ShadowProcess

Struct ShadowProcess 

pub struct ShadowProcess { /* private fields */ }
Provides a hack for truly pinning memory in the absence of partial VMAR profiles or an analogous feature (https://fxbug.dev/446265172). The pins produced by this type will stay pinned even under critical memory pressure levels and should be used with extreme care.

Requires access to the fuchsia.scheduler.RoleManager protocol capability to actually pin memory.

Implementations

Source

impl ShadowProcess

pub fn new(name: Name) -> Result<Self, Status>

Create a new shadow process for pinning memory. Connects to fuchsia.scheduler.RoleManager in the process’ namespace.

pub fn pin_pages( &self, vmo: &Vmo, offset: u64, length: usize, ) -> Result<Arc<PinnedMapping>, Errno>

Pin the provided range of the provided VMO to ensure those pages stay resident under memory pressure.

pub fn vmar(&self) -> Arc<Vmar>

Return a handle to the VMAR where all mappings are pinned.