pub struct ShadowProcess { /* private fields */ }Expand description
Provides a hack for truly pinning memory in the absence of partial VMAR profiles or an analogous feature (https://fxbug.dev/446265172). The pins produced by this type will stay pinned even under critical memory pressure levels and should be used with extreme care.
Requires access to the fuchsia.scheduler.RoleManager protocol capability to actually pin
memory.
Implementations
Sourceimpl ShadowProcess
impl ShadowProcess
Sourcepub fn new(name: Name) -> Result<Self, Status>
pub fn new(name: Name) -> Result<Self, Status>
Create a new shadow process for pinning memory. Connects to fuchsia.scheduler.RoleManager
in the process’ namespace.